# Actions

# Message
All
New
Recent
Username
- users
- text
- price
- /tmp

Message [all, recent, new, $user] users $message with $/tmp image for $price.

## Release
Image
Gallery
Video
- text
- /tmp
- isTweeting

Upload $/tmp as post with $text.

Performer
- text
- performer
- /tmp

Upload $/tmp as post with $text and tag $performer.

Scene
- users
- message
- price
- /tmp/preview
-- text
-- /tmp/content
-- isTweeting 
-- releaseDate (1 week, 2 weeks later, etc)

Message [all, recent, new, $user] users $message with $/tmp/preview image for $price.
On $releaseDate, post $/tmp/content with $text.